@@ -2,7 +2,7 @@ cleaningPatterns <- function(clean){
     if(! clean %in% 1:4){
         stop ("only clean values 1, 2, 3, and 4 are supported")
     }
-    c("nonmem","worker*","FDATA*","fort.*","WK_*")
+    c("nonmem","worker*","FDATA*","fort.*","WK_*","temp_dir","FSUBS*")
 }
 
 ##' Internal function to run Nonmem on linux
@@ -10,9 +10,14 @@ cleaningPatterns <- function(clean){
 ##' @keywords internal
 NMrunLin <- function(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem,clean,sge,nc,pnm){
 
+    rm.if.pres <- function(regex){
+        sprintf("find . -type f -name \"%s\" -exec rm {} \\;",regex)     
+    }
+
+
     name <- NULL
     fn.lst <- fnExtension( fn.mod,".lst")
-    
+    line.run <- sprintf("%s %s %s",path.nonmem,fn.mod,fn.lst)    
     if(sge){
         ## executing from model execution dir.
         jobname <- sub(pattern="^ *",replacement="", x=basename(fn.mod) )
@@ -20,45 +25,46 @@ NMrunLin <- function(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem,clean,sg
         if(grepl("^[0-9]",jobname)) {
             jobname <- paste0("NMsim_",jobname)
         }
-        
-        line.run <- sprintf('qsub -pe orte %s -V -N \"%s\" -j y -cwd -b y \"%s\" -background -parafile=%s [nodes]=%s'
+        line.run <- sprintf('qsub -pe orte %s -V -N \"%s\" -j y -cwd -b y \"%s\" -background'
                            ,
                             nc
                            ,
                             jobname
                            ,
+                            line.run
                             ## paste(path.nonmem,basename(fn.mod),fnExtension( basename(fn.mod),".lst"),"; echo DONE > NMexec_complete.txt")
-                            paste(path.nonmem,fn.mod,fn.lst)
-                              ##,basename(pnm)
-                             ,getAbsolutePath(pnm)
-                             ,nc
-                              )
+                            ##paste(path.nonmem,fn.mod,fn.lst)
+                            ## ,basename(pnm)
+                            ## ,getAbsolutePath(pnm)
+                            ## ,nc
+                            )
+
+        if(nc>1){
+            line.run <- sprintf('%s -parafile=\"%s\" [nodes]=%s',line.run,getAbsolutePath(pnm),nc)
+        }
         
         ## line.run <- sprintf("qsub -pe orte %s -V -N %s %s %s",
         ##                     nc
         ##                    ,jobname
         ##                     path.nonmem,fn.mod,fnExtension(fn.mod,".lst"))
         
-    } else {
-        line.run <- sprintf("%s %s %s",path.nonmem,fn.mod,fn.lst)
     }
-
     lines.bash <- c(
         "#!/bin/bash"
-        ,""
+       ,""
        ,line.run
-       ,"stat=$?"
-       ,"if [ $stat -ne 0 ]; then"
-       ,"exit $stat;"
-       ,"fi"
-        ,sprintf("until [ -f %s ]; do",fn.lst)
-        ,"sleep 2"
-       ,"done"
-       ## ,sprintf("( tail -f -n4 %s & ) | grep -q \"Stop Time:\"",fn.lst)
-       ## ,"echo Stop found"
-         ,sprintf("while ! grep -q \"Stop Time\" %s ; do",fn.lst)
+       ## ,"stat=$?"
+       ## ,"if [ $stat -ne 0 ]; then"
+       ## ,"exit $stat;"
+       ## ,"fi"
+       ,sprintf("until [ -f %s ]; do",fn.lst)
        ,"sleep 2"
-         ,"done"
+       ,"done"
+        ## ,sprintf("( tail -f -n4 %s & ) | grep -q \"Stop Time:\"",fn.lst)
+        ## ,"echo Stop found"
+       ,sprintf("while ! grep -q \"Stop Time\" %s ; do",fn.lst)
+       ,"sleep 2"
+       ,"done"
 ### copy output tables back
         ## ,sprintf("cp \'%s\' \'%s\'",paste(meta.tables[,name],collapse="' '"),dir.mod.abs)
        ,paste0("find . -type f -name ",paste0("\'",meta.tables[,name],"\'")," -exec cp {} \'",dir.mod.abs,"\' \\;")
@@ -67,10 +73,6 @@ NMrunLin <- function(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem,clean,sg
        ,""
     )
 
-    rm.if.pres <- function(regex){
-        sprintf("find . -type f -name \"%s\" -exec rm {} \\;",regex)     
-    }
-
     if(clean>0 && clean<5){
 
         patterns.clean <- cleaningPatterns(clean)
@@ -85,7 +87,6 @@ NMrunLin <- function(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem,clean,sg
                         sprintf("cd ..; rm -r \"%s\"",dir.mod.abs)
                         )
     }
-    
     lines.bash
 }
 
